==> paystack-ui-0.0.9-sources.jar: com/paystack/android/ui/theme/Color.kt <==
package com.paystack.android.ui.theme

import androidx.compose.ui.graphics.Color
import com.paystack.androiddesignsystem.colors.PaystackColors

internal val md_theme_light_primary = Color(0xFF006689)
internal val md_theme_light_onPrimary = Color(0xFFFFFFFF)
internal val md_theme_light_primaryContainer = Color(0xFFC2E8FF)
internal val md_theme_light_onPrimaryContainer = Color(0xFF001E2C)
internal val md_theme_light_secondary = Color(0xFF006E2E)
internal val md_theme_light_onSecondary = Color(0xFFFFFFFF)
internal val md_theme_light_secondaryContainer = Color(0xFF82FC98)
internal val md_theme_light_onSecondaryContainer = Color(0xFF002109)
internal val md_theme_light_tertiary = Color(0xFF00629E)
internal val md_theme_light_onTertiary = Color(0xFFFFFFFF)
internal val md_theme_light_tertiaryContainer = Color(0xFFCFE4FF)
internal val md_theme_light_onTertiaryContainer = Color(0xFF001D34)
internal val md_theme_light_error = Color(0xFFBA1A1A)
internal val md_theme_light_errorContainer = Color(0xFFFFDAD6)
internal val md_theme_light_onError = Color(0xFFFFFFFF)
internal val md_theme_light_onErrorContainer = Color(0xFF410002)
internal val md_theme_light_background = Color(0xFFF8FDFF)
internal val md_theme_light_onBackground = Color(0xFF001F25)
internal val md_theme_light_surface = Color(0xFFF8FDFF)
internal val md_theme_light_onSurface = Color(0xFF001F25)
internal val md_theme_light_surfaceVariant = Color(0xFFDCE3E9)
internal val md_theme_light_onSurfaceVariant = Color(0xFF41484D)
internal val md_theme_light_outline = Color(0xFF71787D)
internal val md_theme_light_inverseOnSurface = Color(0xFFD6F6FF)
internal val md_theme_light_inverseSurface = Color(0xFF00363F)
internal val md_theme_light_inversePrimary = Color(0xFF78D1FF)
internal val md_theme_light_shadow = Color(0xFF000000)
internal val md_theme_light_surfaceTint = Color(0xFF006689)
internal val md_theme_light_outlineVariant = Color(0xFFC0C7CD)
internal val md_theme_light_scrim = Color(0xFF000000)

internal val md_theme_dark_primary = Color(0xFF78D1FF)
internal val md_theme_dark_onPrimary = Color(0xFF003549)
internal val md_theme_dark_primaryContainer = Color(0xFF004D68)
internal val md_theme_dark_onPrimaryContainer = Color(0xFFC2E8FF)
internal val md_theme_dark_secondary = Color(0xFF65DE7F)
internal val md_theme_dark_onSecondary = Color(0xFF003914)
internal val md_theme_dark_secondaryContainer = Color(0xFF005321)
internal val md_theme_dark_onSecondaryContainer = Color(0xFF82FC98)
internal val md_theme_dark_tertiary = Color(0xFF9ACBFF)
internal val md_theme_dark_onTertiary = Color(0xFF003355)
internal val md_theme_dark_tertiaryContainer = Color(0xFF004A79)
internal val md_theme_dark_onTertiaryContainer = Color(0xFFCFE4FF)
internal val md_theme_dark_error = Color(0xFFFFB4AB)
internal val md_theme_dark_errorContainer = Color(0xFF93000A)
internal val md_theme_dark_onError = Color(0xFF690005)
internal val md_theme_dark_onErrorContainer = Color(0xFFFFDAD6)
internal val md_theme_dark_background = Color(0xFF001F25)
internal val md_theme_dark_onBackground = Color(0xFFA6EEFF)
internal val md_theme_dark_surface = Color(0xFF001F25)
internal val md_theme_dark_onSurface = Color(0xFFA6EEFF)
internal val md_theme_dark_surfaceVariant = Color(0xFF41484D)
internal val md_theme_dark_onSurfaceVariant = Color(0xFFC0C7CD)
internal val md_theme_dark_outline = Color(0xFF8A9297)
internal val md_theme_dark_inverseOnSurface = Color(0xFF001F25)
internal val md_theme_dark_inverseSurface = Color(0xFFA6EEFF)
internal val md_theme_dark_inversePrimary = Color(0xFF006689)
internal val md_theme_dark_shadow = Color(0xFF000000)
internal val md_theme_dark_surfaceTint = Color(0xFF78D1FF)
internal val md_theme_dark_outlineVariant = Color(0xFF41484D)
internal val md_theme_dark_scrim = Color(0xFF000000)

internal val seed = Color(0xFF04A5DB)

internal val PaystackColors.pinInputUnfocusedBorderColor
    get() = Color(0xFFE4E4E4)

internal val PaystackColors.countdownProgressTrackColor
    get() = Color(0xFFF0F0F0)

==> paystack-ui-0.0.10-sources.jar: com/paystack/android/ui/theme/Color.kt <==
package com.paystack.android.ui.theme

import androidx.compose.ui.graphics.Color
import com.paystack.android.ui.theme.colors.PaystackColors

internal val md_theme_light_primary = Color(0xFF006689)
internal val md_theme_light_onPrimary = Color(0xFFFFFFFF)
internal val md_theme_light_primaryContainer = Color(0xFFC2E8FF)
internal val md_theme_light_onPrimaryContainer = Color(0xFF001E2C)
internal val md_theme_light_secondary = Color(0xFF006E2E)
internal val md_theme_light_onSecondary = Color(0xFFFFFFFF)
internal val md_theme_light_secondaryContainer = Color(0xFF82FC98)
internal val md_theme_light_onSecondaryContainer = Color(0xFF002109)
internal val md_theme_light_tertiary = Color(0xFF00629E)
internal val md_theme_light_onTertiary = Color(0xFFFFFFFF)
internal val md_theme_light_tertiaryContainer = Color(0xFFCFE4FF)
internal val md_theme_light_onTertiaryContainer = Color(0xFF001D34)
internal val md_theme_light_error = Color(0xFFBA1A1A)
internal val md_theme_light_errorContainer = Color(0xFFFFDAD6)
internal val md_theme_light_onError = Color(0xFFFFFFFF)
internal val md_theme_light_onErrorContainer = Color(0xFF410002)
internal val md_theme_light_background = Color(0xFFF8FDFF)
internal val md_theme_light_onBackground = Color(0xFF001F25)
internal val md_theme_light_surface = Color(0xFFF8FDFF)
internal val md_theme_light_onSurface = Color(0xFF001F25)
internal val md_theme_light_surfaceVariant = Color(0xFFDCE3E9)
internal val md_theme_light_onSurfaceVariant = Color(0xFF41484D)
internal val md_theme_light_outline = Color(0xFF71787D)
internal val md_theme_light_inverseOnSurface = Color(0xFFD6F6FF)
internal val md_theme_light_inverseSurface = Color(0xFF00363F)
internal val md_theme_light_inversePrimary = Color(0xFF78D1FF)
internal val md_theme_light_shadow = Color(0xFF000000)
internal val md_theme_light_surfaceTint = Color(0xFF006689)
internal val md_theme_light_outlineVariant = Color(0xFFC0C7CD)
internal val md_theme_light_scrim = Color(0xFF000000)

internal val md_theme_dark_primary = Color(0xFF78D1FF)
internal val md_theme_dark_onPrimary = Color(0xFF003549)
internal val md_theme_dark_primaryContainer = Color(0xFF004D68)
internal val md_theme_dark_onPrimaryContainer = Color(0xFFC2E8FF)
internal val md_theme_dark_secondary = Color(0xFF65DE7F)
internal val md_theme_dark_onSecondary = Color(0xFF003914)
internal val md_theme_dark_secondaryContainer = Color(0xFF005321)
internal val md_theme_dark_onSecondaryContainer = Color(0xFF82FC98)
internal val md_theme_dark_tertiary = Color(0xFF9ACBFF)
internal val md_theme_dark_onTertiary = Color(0xFF003355)
internal val md_theme_dark_tertiaryContainer = Color(0xFF004A79)
internal val md_theme_dark_onTertiaryContainer = Color(0xFFCFE4FF)
internal val md_theme_dark_error = Color(0xFFFFB4AB)
internal val md_theme_dark_errorContainer = Color(0xFF93000A)
internal val md_theme_dark_onError = Color(0xFF690005)
internal val md_theme_dark_onErrorContainer = Color(0xFFFFDAD6)
internal val md_theme_dark_background = Color(0xFF001F25)
internal val md_theme_dark_onBackground = Color(0xFFA6EEFF)
internal val md_theme_dark_surface = Color(0xFF001F25)
internal val md_theme_dark_onSurface = Color(0xFFA6EEFF)
internal val md_theme_dark_surfaceVariant = Color(0xFF41484D)
internal val md_theme_dark_onSurfaceVariant = Color(0xFFC0C7CD)
internal val md_theme_dark_outline = Color(0xFF8A9297)
internal val md_theme_dark_inverseOnSurface = Color(0xFF001F25)
internal val md_theme_dark_inverseSurface = Color(0xFFA6EEFF)
internal val md_theme_dark_inversePrimary = Color(0xFF006689)
internal val md_theme_dark_shadow = Color(0xFF000000)
internal val md_theme_dark_surfaceTint = Color(0xFF78D1FF)
internal val md_theme_dark_outlineVariant = Color(0xFF41484D)
internal val md_theme_dark_scrim = Color(0xFF000000)

internal val seed = Color(0xFF04A5DB)

internal val PaystackColors.pinInputUnfocusedBorderColor
    get() = Color(0xFFE4E4E4)

internal val PaystackColors.countdownProgressTrackColor
    get() = Color(0xFFF0F0F0)
